# Be sure to restart your server when you modify this file.

# Your secret key for verifying the integrity of signed cookies.
# If you change this key, all old signed cookies will become invalid!
# Make sure the secret is at least 30 characters and all random,
# no regular words or you'll be exposed to dictionary attacks.
Dummy::Application.config.secret_token = 'd7f814755d70d615d32ad7cbf4bfbcf2c42546dfd4cb0f893063d89986adbfca609029280fb55197379a9494110237790c033534aa4a8cc02aacf985564d368d'
